API docs for “spamfighter.core.firewall.FirewallStatement”

# Class s.c.f.FirewallStatement(object):

Part of spamfighter.core.firewall View Source View In Hierarchy

Known subclasses: spamfighter.core.firewall.DoFirewallStatement, spamfighter.core.firewall.SkipFirewallStatement, spamfighter.core.firewall.StopFirewallStatement

Класс, инкаспилирующий одно правило файрвола.

Конкретные наследники реализуют конкретные правила.

Instance Variables | if_tags | набор тегов, по которым идёт фильтрация применения правила (type: `list` )
| if_inverted | инвертированный смысл условия по if (if not?) (type: `bool` )
| label | метка правила (type: `int` )

Method | __init__ | Конструктор.
Method | __eq__ | Undocumented
Method | __repr__ | Undocumented
Method | __str__ | Получить строковое представление правила (в исходной грамматике).
Method | compile | Скомпилировать правило, присоединив его к цепочке deferred.
Method | _if_helper | Элемент цепочки отложенных вызовов, отвечающий за обработку условия.
Method | _label_helper | Errback, который ловит `SkipToProcess`, чтобы обеcпечить остановку

def __init__(self, if_tags=None, if_inverted=False, label=None): (source)
overridden in spamfighter.core.firewall.DoFirewallStatement, spamfighter.core.firewall.SkipFirewallStatement, spamfighter.core.firewall.StopFirewallStatement
Конструктор.

Parameters | if_tags | набор тегов, по которым идёт фильтрация применения правила (type: `list` )
| if_inverted | инвертированный смысл условия по if (if not?) (type: `bool` )
| label | метка правила (type: `int` )

def __eq__(self, other): (source)
overridden in spamfighter.core.firewall.DoFirewallStatement, spamfighter.core.firewall.SkipFirewallStatement, spamfighter.core.firewall.StopFirewallStatement
Undocumented
def __repr__(self): (source)
overridden in spamfighter.core.firewall.DoFirewallStatement, spamfighter.core.firewall.SkipFirewallStatement, spamfighter.core.firewall.StopFirewallStatement
Undocumented
def __str__(self): (source)
overridden in spamfighter.core.firewall.DoFirewallStatement, spamfighter.core.firewall.SkipFirewallStatement, spamfighter.core.firewall.StopFirewallStatement
Получить строковое представление правила (в исходной грамматике).

Returns | (type: `str` )

def compile(self, d, debug=False): (source)
overridden in spamfighter.core.firewall.DoFirewallStatement, spamfighter.core.firewall.SkipFirewallStatement, spamfighter.core.firewall.StopFirewallStatement
Скомпилировать правило, присоединив его к цепочке deferred.

Parameters | d | цепочка отложенных вызовов (type: `twisted.internet.defer.Deferred` )
| debug | включить отладочный режим? (type: `bool` )

def _if_helper(self, message): (source)
Элемент цепочки отложенных вызовов, отвечающий за обработку условия.

Parameters | message | обрабатываемое сообщение (type: `ITaggedMessage` )
Returns | результат обработки сообщения (type: `bool` )

def _label_helper(self, failure, debug=False): (source)
Errback, который ловит `SkipToProcess`, чтобы обеcпечить остановку на нужном label после skip to.

Parameters | debug | включить отладочный режим? (type: `bool` )